# GitInstaller

[![Coverage Status](https://coveralls.io/repos/github/ychnlgy/GitInstaller/badge.svg?branch=master)](https://coveralls.io/github/ychnlgy/GitInstaller?branch=master)
[![Build Status](https://travis-ci.org/ychnlgy/GitInstaller.png)](https://travis-ci.org/ychnlgy/GitInstaller)
[![PyPI version](https://badge.fury.io/py/git-install.svg)](https://pypi.python.org/pypi/git-install)
[![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)

Installs GitHub packages to your current directory using **[python3](https://www.python.org/downloads/)**.

## Installation using [pip3](https://pypi.python.org/pypi/pip)
```bash
pip3 install git-install
```

## Quickstart
 - Install package [```ychnlgy/Standard```](https://github.com/ychnlgy/Standard):
 ```bash
 git-install.py ychnlgy/Standard
 ```
 - Uninstall [```ychnlgy/Standard```](https://github.com/ychnlgy/Standard):
 ```bash
 git-install.py --uninstall ychnlgy/Standard
 ```
 - Dependencies are installed if necessary. Here we install [```ychnlgy/UnitTest```](https://github.com/ychnlgy/UnitTest), which depends on [```ychnlgy/Standard```](https://github.com/ychnlgy/Standard):
 ```bash
 git-install.py ychnlgy/UnitTest
 ```
 - To remove all installed packages, do:
 ```bash
 git-install.py --removeall
 ```
 
## Additional features
 - List all installed packages:
 ```bash
 git-install.py --list
 ```
 - Reinstall a package:
 ```bash
 git-install.py --reinstall ychnlgy/Standard
 ```
 - Install the required packages specified in ```git-install.ini``` (see below):
 ```bash
 git-install.py --setup
 ```

## What is ```git-install.ini```?
For a C++ project that depends on [```ychnlgy/Standard```](https://github.com/ychnlgy/Standard) and [```ychnlgy/UnitTest```](https://github.com/ychnlgy/UnitTest), you would typically write:
```ini
INCLUDE = *.cpp *.h
EXCLUDE = */tests
REQUIRE = ychnlgy/Standard ychnlgy/UnitTest
```
Here is a detailed explanation of the fields (which accept multiple space-separated arguments):

  | Option        | Description                                               |
  |---------------|-----------------------------------------------------------|
  | ```INCLUDE``` | Patterns of files to include during installation.         |
  | ```EXCLUDE``` | Patterns of files/folders to exclude.*                    |
  | ```REQUIRE``` | Other git-installable packages required by this package.  |

\* Note: any file that is excluded or not included is deleted during installation.

## How to set up your own git-installable package (3 steps):

 1. Make sure that packaged files are within a subfolder of the same name - but lower case! This means if your package is ```ychnlgy/Standard```, the GitHub repository should contain ```standard/``` at its root directory. Other files or folders are deleted during installation!
 2. Write a ```git-install.ini``` containing the patterns of included and excluded files, and all git-installable dependencies.
 3. Push to GitHub.

## What is ```git-installed.log```?

It stores the names of all git-installed packages so ```git-install.py --uninstall``` and ```git-install.py --removeall``` do not accidently delete your important folders.
