from os import path, fsync, remove, rmdir, listdir
import json

from filesys.tools import parse, write

class InstalledLog:
	def __init__(self, fname):
		self.fname = fname
		self.data = {}
	
	def show(self):
		return list(sorted(self.data.keys()))
	
	def has(self, pkg):
		return pkg.lower() in self.data
	
	def add(self, pkg, binaries):
		if not self.has(pkg):
			self.data[pkg.lower()] = binaries
	
	def getBinaries(self, pkg):
		return self.data[pkg.lower()]
	
	def rm(self, pkg):
		if self.has(pkg):
			self.data.pop(pkg.lower())
	
	def __enter__(self):
		self.parse()
		return self
		
	def __exit__(self, *args):
		self.write()
		self.cleanup()
	
	# === PRIVATE METHODS ===
	
	def write(self):
		write(self.fname, self.strData())
	
	def cleanup(self):
		if not self.data:
			remove(self.fname)
	
	def parse(self):
		if path.isfile(self.fname):
			lines = "\n".join(parse(self.fname))
			self.data = json.loads(lines)
	
	def strData(self):
		return json.dumps(self.data)
